CompressionEffort

Enum CompressionEffort 

pub enum CompressionEffort {
    Balanced,
    Smallest,
}
JPEG compression effort used during encoding. JPEG compression effort.

This setting is orthogonal to whether the JPEG is encoded as sequential or progressive.

Smallest requests the most size-oriented encoder configuration available for the chosen scan mode.

With the current mozjpeg-based backend, the additional size-oriented scan optimization only affects progressive output. Sequential output still accepts Smallest for API consistency, but currently uses the same effective backend settings as Balanced.

Variants



Balanced

Balanced size and encode time.



Smallest

Favor smaller output over encode time.